@@ -58,7 +58,6 @@
 			
 			plugin.init = function() {
 				plugin.getDefault()
-				// console.log('*****plugin.settingsgffgfg*********',plugin.settings)
 				if (plugin.initiator.data_h && plugin.initiator.data_w && plugin.initiator.data_x && plugin.initiator.data_y) {
 					plugin.initiator.defaultCrop = { "width": parseFloat(plugin.initiator.data_w), "height": parseFloat(plugin.initiator.data_h),"x" : parseFloat(plugin.initiator.data_x),"y" : parseFloat(plugin.initiator.data_y),"rotate" : parseFloat(plugin.initiator.data_r)};
 				} 
@@ -123,7 +122,6 @@
 			},
 			plugin.getCanvas= function(settings =plugin.settings , imagetype =plugin.default_ext){
 				canvas =''
-				console.log('*********getCanvas*settings********8',settings,settings.orginal_extension,imagetype)
 				if (settings.orginal_extension==true && plugin.uploadedImageType !=plugin.default_ext ){
 					canvas = plugin.cropper.getCroppedCanvas().toDataURL()
 				} else{
@@ -441,7 +439,6 @@
 				if(type =="compress" && image.width >= parseFloat(settings.maxmainimagewidth)){
 					comps_ratio = image.width/parseFloat(settings.maxmainimagewidth)
 				}
-				console.log('**********imagefggfg******')
 				canvas.width=image.width/comps_ratio;
 				canvas.height=image.height/comps_ratio;
 				context.drawImage(image,
